<?php

namespace App\Exports;

use App\Models\UsersKPI;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromQuery;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithMapping;

class UserKPISExport implements WithMapping, WithHeadings,FromQuery
{

    public function query()
    {
        $users=UsersKPI::query()->select('users_kpis.id','users_kpis.kpi_id','departments.title AS department','users.name AS user_name','users.hr_id AS user_hr_id','users_kpis.user_id','users_kpis.year','users_kpis.month','users_kpis.total_employee_score','users_kpis.created_at',DB::raw("DATE_FORMAT(CAST(CONCAT(users_kpis.year,'-',users_kpis.month,'-01') AS DATE),'%Y-%m')  AS `year_month`"))->has('KPI')->has('User')
            ->leftJoin('users','users.id','=','users_kpis.user_id')
            ->leftJoin('kpis','kpis.id','=','users_kpis.kpi_id')
            ->leftJoin('departments','departments.id','=','kpis.department_id')
        ;
        if(!PerUser('users_kpis.show_all')){
            $users=$users->whereHas('User',function($q){
                return$q->where('path','LIKE','%:'.auth()->id().'::%');
            });
        }
        if(request('search_by')=='created_at'&&request('start_date')&&request('end_date')){
            $users=$users->whereBetween(DB::raw("DATE_FORMAT(users_kpis.created_at,'%Y-%m-%d')"),[request('start_date'),request('end_date')]);
        }
        if(request('search_by')=='year_month'&&request('start_date')&&request('end_date')){
            $start_date=request('start_date');
            $end_date=request('end_date');
            $users=$users->whereRaw("DATE_FORMAT(CAST(CONCAT(users_kpis.year,'-',users_kpis.month,'-01') AS DATE),'%Y-%m')  BETWEEN DATE_FORMAT('$start_date','%Y-%m') AND DATE_FORMAT('$end_date','%Y-%m')");
        }
        if(request('department_id')){
            $users=$users->where('departments.id',request('department_id'));
        }
        if(request('IDS')){
            $users=$users->whereIn('users_kpis.id',explode(',',request('IDS')));
        }
        return $users;
    }
    /**
    * @return \Illuminate\Support\Collection
    */

    public function map($user_kpi) : array {
        return [

            $user_kpi->user_hr_id,
            $user_kpi->user_name,
            $user_kpi->department,
            $user_kpi->year_month,
            $user_kpi->total_employee_score,
            $user_kpi->created_at?$user_kpi->created_at->format('d M Y, h:i a'):'',

        ] ;
    }
    public function headings() : array {
        return [
            __('HR ID'),
            __('Employee Name'),
            __('KPI Name'),
            __('Year & Month'),
            __('Total Employee Score'),
            __('Created At')
        ] ;
    }
}
